#pragma once

#include <d3d11.h>
#include <DirectXMath.h>
using namespace DirectX;

class depth_shader_class
{
public:
    depth_shader_class();
    ~depth_shader_class();

    bool initialize(ID3D11Device* device, HWND hwnd);
    void shutdown();
    bool render(ID3D11DeviceContext* deviceContext, int indexCount, 
                XMMATRIX worldMatrix, XMMATRIX viewMatrix, XMMATRIX projectionMatrix);

private:
    struct MatrixBufferType
    {
        XMMATRIX world;
        XMMATRIX view;
        XMMATRIX projection;
    };

    bool initialize_shader(ID3D11Device* device, HWND hwnd, const WCHAR* vsFilename, const WCHAR* psFilename);
    void shutdown_shader();
    void output_shader_error_message(ID3D10Blob* errorMessage, HWND hwnd, const WCHAR* shaderFilename);
    bool set_shader_parameters(ID3D11DeviceContext* deviceContext, 
                              XMMATRIX worldMatrix, XMMATRIX viewMatrix, XMMATRIX projectionMatrix);
    void render_shader(ID3D11DeviceContext* deviceContext, int indexCount);

    ID3D11VertexShader* vertex_shader_;
    ID3D11PixelShader* pixel_shader_;
    ID3D11InputLayout* layout_;
    ID3D11Buffer* matrix_buffer_;
};